package su.a71.new_soviet.datagen;

import net.minecraft.advancement.Advancement;
import net.minecraft.advancement.AdvancementFrame;
import net.minecraft.advancement.criterion.InventoryChangedCriterion;
import net.minecraft.advancement.criterion.OnKilledCriterion;
import net.minecraft.advancement.criterion.UsingItemCriterion;
import net.minecraft.entity.EntityType;
import net.minecraft.item.Items;
import net.minecraft.predicate.NumberRange;
import net.minecraft.predicate.entity.DamageSourcePredicate;
import net.minecraft.predicate.entity.EntityEquipmentPredicate;
import net.minecraft.predicate.entity.EntityPredicate;
import net.minecraft.predicate.entity.PlayerPredicate;
import net.minecraft.predicate.item.ItemPredicate;
import net.minecraft.stat.Stats;
import net.minecraft.text.Text;
import net.minecraft.util.Identifier;
import net.minecraft.util.UseAction;
import su.a71.new_soviet.NewSoviet;
import su.a71.new_soviet.items.DiceItem;
import su.a71.new_soviet.registration.NSE_Items;
import su.a71.new_soviet.registration.NSE_Stats;
import su.a71.new_soviet.registration.NSE_Tags;

import java.util.function.Consumer;

public class Advancements implements Consumer<Consumer<Advancement>> {
    @Override
    public void accept(Consumer<Advancement> consumer) {
        Advancement root = Advancement.Builder.create()
                .display(
                        NSE_Items.SICKLE,
                        Text.translatable("advancement.new_soviet.root.name"),
                        Text.translatable("advancement.new_soviet.root.desc"),
                        new Identifier("textures/gui/advancements/backgrounds/adventure.png"),
                        AdvancementFrame.TASK,
                        false,  // Toast
                        false, // Announcement
                        false // Hidden
                )
                .criterion("got_dirt", InventoryChangedCriterion.Conditions.items(Items.DIRT))
                .build(consumer, NewSoviet.MOD_ID + "/root");

        // Make a sickle
        Advancement sickle = Advancement.Builder.create()
                .display(
                        NSE_Items.SICKLE,
                        Text.translatable("advancement.new_soviet.sickle.name"),
                        Text.translatable("advancement.new_soviet.sickle.desc"),
                        new Identifier("textures/gui/advancements/backgrounds/adventure.png"),
                        AdvancementFrame.TASK,
                        true,  // Toast
                        true, // Announcement
                        false // Hidden
                )
                .parent(root)
                .criterion("got_sickle", InventoryChangedCriterion.Conditions.items(NSE_Items.SICKLE))
                .build(consumer, NewSoviet.MOD_ID + "/sickle");

        // Kill someone with a sickle
        Advancement sickle_kill = Advancement.Builder.create()
                .display(
                        NSE_Items.SICKLE,
                        Text.translatable("advancement.new_soviet.sickle_kill.name"),
                        Text.translatable("advancement.new_soviet.sickle_kill.desc"),
                        new Identifier("textures/gui/advancements/backgrounds/adventure.png"),
                        AdvancementFrame.TASK,
                        true,  // Toast
                        true, // Announcement
                        false // Hidden
                )
                .parent(sickle)
                .criterion("got_sickle", InventoryChangedCriterion.Conditions.items(NSE_Items.SICKLE))
                .criterion("kill", OnKilledCriterion.Conditions.createPlayerKilledEntity(EntityPredicate.Builder.create(), DamageSourcePredicate.Builder.create().sourceEntity(EntityPredicate.Builder.create().equipment(EntityEquipmentPredicate.Builder.create().mainhand(ItemPredicate.Builder.create().items(NSE_Items.SICKLE).build()).build()))))
                .build(consumer, NewSoviet.MOD_ID + "/sickle_kill");


        // Throw a die 100 times
        Advancement gambler = Advancement.Builder.create()
                .display(
                        NSE_Items.DICE_D6,
                        Text.translatable("advancement.new_soviet.gambler.name"),
                        Text.translatable("advancement.new_soviet.gambler.desc"),
                        new Identifier("textures/gui/advancements/backgrounds/adventure.png"),
                        AdvancementFrame.TASK,
                        true,  // Toast
                        true, // Announcement
                        false // Hidden
                )
                .parent(root)
                .criterion("rolled_100", UsingItemCriterion.Conditions.create(
                        EntityPredicate.Builder.create().type(EntityType.PLAYER).typeSpecific(PlayerPredicate.Builder.create().stat(Stats.CUSTOM.getOrCreateStat(NSE_Stats.ROLL_ANY_DICE), NumberRange.IntRange.atLeast(100)).build()),
                        ItemPredicate.Builder.create().tag(NSE_Tags.Items.DICE)))
                .build(consumer, NewSoviet.MOD_ID + "/gambler");

//         Throw a die 1000 times
        Advancement serious_addiction = Advancement.Builder.create()
                .display(
                        NSE_Items.DICE_D20,
                        Text.translatable("advancement.new_soviet.serious_addiction.name"),
                        Text.translatable("advancement.new_soviet.serious_addiction.desc"),
                        new Identifier("textures/gui/advancements/backgrounds/adventure.png"),
                        AdvancementFrame.CHALLENGE,
                        true,  // Toast
                        true, // Announcement
                        false // Hidden
                )
                .criterion("rolled_1000", UsingItemCriterion.Conditions.create(EntityPredicate.Builder.create().type(EntityType.PLAYER).typeSpecific(PlayerPredicate.Builder.create().stat(Stats.CUSTOM.getOrCreateStat(NSE_Stats.ROLL_ANY_DICE), NumberRange.IntRange.atLeast(1000)).build()), ItemPredicate.Builder.create().tag(NSE_Tags.Items.DICE)))
                .parent(gambler)
                .build(consumer, NewSoviet.MOD_ID + "/serious_addiction");

        // Roll perfect die 100 times
        Advancement lucky_throw = Advancement.Builder.create()
                .display(
                        NSE_Items.DICE_D4,
                        Text.translatable("advancement.new_soviet.lucky_throw.name"),
                        Text.translatable("advancement.new_soviet.lucky_throw.desc"),
                        new Identifier("textures/gui/advancements/backgrounds/adventure.png"),
                        AdvancementFrame.CHALLENGE,
                        true,  // Toast
                        true, // Announcement
                        false // Hidden
                )
                .parent(gambler)
                .criterion("rolled_100_perfect", UsingItemCriterion.Conditions.create(EntityPredicate.Builder.create().type(EntityType.PLAYER).typeSpecific(PlayerPredicate.Builder.create().stat(Stats.CUSTOM.getOrCreateStat(NSE_Stats.ROLL_PERFECT_DICE), NumberRange.IntRange.atLeast(100)).build()), ItemPredicate.Builder.create().tag(NSE_Tags.Items.DICE)))
                .build(consumer, NewSoviet.MOD_ID + "/lucky_throw");
    }
}
